@@ -88,6 +88,7 @@ class BaseProject:
         X_test : Optional[Union["np.ndarray", "torch.Tensor", "pd.DataFrame"]] = None,
         y_test : Optional[Union["np.ndarray", "torch.Tensor", "pd.DataFrame"]] = None,
         n_classes : Optional[int] = None,
+        stratify : bool = True,
         path : str = "."
     )->None:
         r"""Creates a ``Project``.
@@ -109,6 +110,9 @@ class BaseProject:
             n_classes (int): Number of classes for the classification task. Don't specify this when performing regression tasks.
                 Default: ``None``
 
+            stratify (bool): Whether to use label-stratification in splitting data into train/val/test set.
+                Default: ``True``
+            
             path (str): Base path for the project. Default is the current directory.
                 Default: ``'.'``
 
@@ -123,6 +127,7 @@ class BaseProject:
         self.y_test = y_test
         self.n_classes = n_classes
         self.path = path
+        self.stratify = stratify
         if self.path[-1] == "/":
             self.path = self.path[:-1] # format path
         
@@ -219,7 +224,8 @@ class BaseProject:
             'y_test' : self.y_test,
             'test_size' : test_size,
             'stack_models' : stack_models,
-            'path' : self.path
+            'path' : self.path,
+            'stratify' : self.stratify
         }
         
         temp_exps = {}
@@ -1037,6 +1043,7 @@ class Project(BaseProject):
         X_test : Optional["np.ndarray"] = None,
         y_test : Optional["np.ndarray"] = None,
         n_classes : Optional[int] = None,
+        stratify : bool = True,
         path : str = "."
     )->None:
         r"""
@@ -1057,7 +1064,10 @@ class Project(BaseProject):
 
             n_classes : Number of classes for the classification task. Don't specify this when performing regression tasks.
                 Default: ``None``
-
+            
+            stratify (bool): Whether to use label-stratification in splitting data into train/val/test set.
+                Default: ``True``
+            
             path : Base path for the project. Default is the current directory.
                 Default: ``.``        
         """
@@ -1068,6 +1078,7 @@ class Project(BaseProject):
             X_test=X_test,
             y_test=y_test,
             n_classes=n_classes,
+            stratify=stratify,
             path=path
         )
 
